import typing

import android.app
import android.content
import android.content.res
import android.graphics
import android.graphics.drawable
import android.graphics.text
import android.net
import android.os
import android.text
import android.view
import java
import java.chaquopy
import java.lang
import java.util

class AbsoluteSizeSpan(android.text.ParcelableSpan, MetricAffectingSpan):
    @typing.overload
    def __init__(self, size: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, src: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, size: int | java.jint | java.lang.Integer, dip: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def describeContents(self) -> int: ...
    def getDip(self) -> bool: ...
    def getSize(self) -> int: ...
    def getSpanTypeId(self) -> int: ...
    def toString(self) -> str: ...
    def updateDrawState(self, ds: android.text.TextPaint, /) -> None: ...
    def updateMeasureState(self, ds: android.text.TextPaint, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AlignmentSpan(ParagraphStyle):
    def getAlignment(self) -> android.text.Layout.Alignment: ...

    class Standard(AlignmentSpan, android.text.ParcelableSpan):
        @typing.overload
        def __init__(self, src: android.os.Parcel, /) -> None: ...
        @typing.overload
        def __init__(self, align: android.text.Layout.Alignment, /) -> None: ...
        def describeContents(self) -> int: ...
        def getAlignment(self) -> android.text.Layout.Alignment: ...
        def getSpanTypeId(self) -> int: ...
        def toString(self) -> str: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class BackgroundColorSpan(android.text.ParcelableSpan, CharacterStyle, UpdateAppearance):
    @typing.overload
    def __init__(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, src: android.os.Parcel, /) -> None: ...
    def describeContents(self) -> int: ...
    def getBackgroundColor(self) -> int: ...
    def getSpanTypeId(self) -> int: ...
    def toString(self) -> str: ...
    def updateDrawState(self, textPaint: android.text.TextPaint, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class BulletSpan(LeadingMarginSpan, android.text.ParcelableSpan):
    STANDARD_GAP_WIDTH: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, gapWidth: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, src: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, gapWidth: int | java.jint | java.lang.Integer, color: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, gapWidth: int | java.jint | java.lang.Integer, color: int | java.jint | java.lang.Integer, bulletRadius: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def drawLeadingMargin(self, canvas: android.graphics.Canvas, paint: android.graphics.Paint, x: int | java.jint | java.lang.Integer, dir: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, baseline: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, text: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, first: bool | java.jboolean | java.lang.Boolean, layout: android.text.Layout, /) -> None: ...
    def getBulletRadius(self) -> int: ...
    def getColor(self) -> int: ...
    def getGapWidth(self) -> int: ...
    def getLeadingMargin(self, first: bool | java.jboolean | java.lang.Boolean, /) -> int: ...
    def getSpanTypeId(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CharacterStyle(java.lang.Object):
    def __init__(self) -> None: ...
    def getUnderlying(self) -> CharacterStyle: ...
    def updateDrawState(self, arg1: android.text.TextPaint, /) -> None: ...
    @staticmethod
    def wrap(cs: CharacterStyle, /) -> CharacterStyle: ...

class ClickableSpan(CharacterStyle, UpdateAppearance):
    def __init__(self) -> None: ...
    def onClick(self, arg1: android.view.View, /) -> None: ...
    def toString(self) -> str: ...
    def updateDrawState(self, ds: android.text.TextPaint, /) -> None: ...

class DrawableMarginSpan(LeadingMarginSpan, LineHeightSpan):
    @typing.overload
    def __init__(self, drawable: android.graphics.drawable.Drawable, /) -> None: ...
    @typing.overload
    def __init__(self, drawable: android.graphics.drawable.Drawable, pad: int | java.jint | java.lang.Integer, /) -> None: ...
    def chooseHeight(self, text: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, istartv: int | java.jint | java.lang.Integer, v: int | java.jint | java.lang.Integer, fm: android.graphics.Paint.FontMetricsInt, /) -> None: ...
    def drawLeadingMargin(self, c: android.graphics.Canvas, p: android.graphics.Paint, x: int | java.jint | java.lang.Integer, dir: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, baseline: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, text: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, first: bool | java.jboolean | java.lang.Boolean, layout: android.text.Layout, /) -> None: ...
    def getDrawable(self) -> android.graphics.drawable.Drawable: ...
    def getLeadingMargin(self, first: bool | java.jboolean | java.lang.Boolean, /) -> int: ...
    def getPadding(self) -> int: ...
    def toString(self) -> str: ...

class DynamicDrawableSpan(ReplacementSpan):
    ALIGN_BASELINE: typing.ClassVar[int] = ...
    ALIGN_BOTTOM: typing.ClassVar[int] = ...
    ALIGN_CENTER: typing.ClassVar[int] = ...
    mVerticalAlignment: int = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, verticalAlignment: int | java.jint | java.lang.Integer, /) -> None: ...
    def draw(self, canvas: android.graphics.Canvas, text: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, x: float | java.jfloat | java.lang.Float, top: int | java.jint | java.lang.Integer, y: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, paint: android.graphics.Paint, /) -> None: ...
    def getDrawable(self) -> android.graphics.drawable.Drawable: ...
    def getSize(self, paint: android.graphics.Paint, text: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, fm: android.graphics.Paint.FontMetricsInt, /) -> int: ...
    def getVerticalAlignment(self) -> int: ...
    def toString(self) -> str: ...

class EasyEditSpan(android.text.ParcelableSpan):
    EXTRA_TEXT_CHANGED_TYPE: typing.ClassVar[str] = ...
    TEXT_DELETED: typing.ClassVar[int] = ...
    TEXT_MODIFIED: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, pendingIntent: android.app.PendingIntent, /) -> None: ...
    @typing.overload
    def __init__(self, source: android.os.Parcel, /) -> None: ...
    def describeContents(self) -> int: ...
    def getSpanTypeId(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ForegroundColorSpan(android.text.ParcelableSpan, CharacterStyle, UpdateAppearance):
    @typing.overload
    def __init__(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, src: android.os.Parcel, /) -> None: ...
    def describeContents(self) -> int: ...
    def getForegroundColor(self) -> int: ...
    def getSpanTypeId(self) -> int: ...
    def toString(self) -> str: ...
    def updateDrawState(self, textPaint: android.text.TextPaint, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class IconMarginSpan(LeadingMarginSpan, LineHeightSpan):
    @typing.overload
    def __init__(self, bitmap: android.graphics.Bitmap, /) -> None: ...
    @typing.overload
    def __init__(self, bitmap: android.graphics.Bitmap, pad: int | java.jint | java.lang.Integer, /) -> None: ...
    def chooseHeight(self, text: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, istartv: int | java.jint | java.lang.Integer, v: int | java.jint | java.lang.Integer, fm: android.graphics.Paint.FontMetricsInt, /) -> None: ...
    def drawLeadingMargin(self, c: android.graphics.Canvas, p: android.graphics.Paint, x: int | java.jint | java.lang.Integer, dir: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, baseline: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, text: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, first: bool | java.jboolean | java.lang.Boolean, layout: android.text.Layout, /) -> None: ...
    def getBitmap(self) -> android.graphics.Bitmap: ...
    def getLeadingMargin(self, first: bool | java.jboolean | java.lang.Boolean, /) -> int: ...
    def getPadding(self) -> int: ...
    def toString(self) -> str: ...

class ImageSpan(DynamicDrawableSpan):
    @typing.overload
    def __init__(self, b: android.graphics.Bitmap, /) -> None: ...
    @typing.overload
    def __init__(self, drawable: android.graphics.drawable.Drawable, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, resourceId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, bitmap: android.graphics.Bitmap, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, uri: android.net.Uri, /) -> None: ...
    @typing.overload
    def __init__(self, b: android.graphics.Bitmap, verticalAlignment: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, drawable: android.graphics.drawable.Drawable, verticalAlignment: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, drawable: android.graphics.drawable.Drawable, source: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, resourceId: int | java.jint | java.lang.Integer, verticalAlignment: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, bitmap: android.graphics.Bitmap, verticalAlignment: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, uri: android.net.Uri, verticalAlignment: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, drawable: android.graphics.drawable.Drawable, source: str | java.lang.String, verticalAlignment: int | java.jint | java.lang.Integer, /) -> None: ...
    def getDrawable(self) -> android.graphics.drawable.Drawable: ...
    def getSource(self) -> str | None: ...
    def toString(self) -> str: ...

class LeadingMarginSpan(ParagraphStyle):
    def drawLeadingMargin(self, arg1: android.graphics.Canvas, arg2: android.graphics.Paint, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: java.lang.CharSequence, arg9: int | java.jint | java.lang.Integer, arg10: int | java.jint | java.lang.Integer, arg11: bool | java.jboolean | java.lang.Boolean, arg12: android.text.Layout, /) -> None: ...
    def getLeadingMargin(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> int: ...

    class Standard(LeadingMarginSpan, android.text.ParcelableSpan):
        @typing.overload
        def __init__(self, every: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, src: android.os.Parcel, /) -> None: ...
        @typing.overload
        def __init__(self, first: int | java.jint | java.lang.Integer, rest: int | java.jint | java.lang.Integer, /) -> None: ...
        def describeContents(self) -> int: ...
        def drawLeadingMargin(self, c: android.graphics.Canvas, p: android.graphics.Paint, x: int | java.jint | java.lang.Integer, dir: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, baseline: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, text: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, first: bool | java.jboolean | java.lang.Boolean, layout: android.text.Layout, /) -> None: ...
        def getLeadingMargin(self, first: bool | java.jboolean | java.lang.Boolean, /) -> int: ...
        def getSpanTypeId(self) -> int: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class LeadingMarginSpan2(LeadingMarginSpan, WrapTogetherSpan):
        def getLeadingMarginLineCount(self) -> int: ...

class LineBackgroundSpan(ParagraphStyle):
    def drawBackground(self, arg1: android.graphics.Canvas, arg2: android.graphics.Paint, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: java.lang.CharSequence, arg9: int | java.jint | java.lang.Integer, arg10: int | java.jint | java.lang.Integer, arg11: int | java.jint | java.lang.Integer, /) -> None: ...

    class Standard(LineBackgroundSpan, android.text.ParcelableSpan):
        @typing.overload
        def __init__(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, src: android.os.Parcel, /) -> None: ...
        def describeContents(self) -> int: ...
        def drawBackground(self, canvas: android.graphics.Canvas, paint: android.graphics.Paint, left: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, baseline: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, text: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, lineNumber: int | java.jint | java.lang.Integer, /) -> None: ...
        def getColor(self) -> int: ...
        def getSpanTypeId(self) -> int: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class LineBreakConfigSpan(android.text.ParcelableSpan):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[LineBreakConfigSpan]] = ...
    def __init__(self, lineBreakConfig: android.graphics.text.LineBreakConfig, /) -> None: ...
    @staticmethod
    def createNoBreakSpan() -> LineBreakConfigSpan: ...
    @staticmethod
    def createNoHyphenationSpan() -> LineBreakConfigSpan: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getLineBreakConfig(self) -> android.graphics.text.LineBreakConfig: ...
    def getSpanTypeId(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class LineHeightSpan(WrapTogetherSpan, ParagraphStyle):
    def chooseHeight(self, arg1: java.lang.CharSequence, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: android.graphics.Paint.FontMetricsInt, /) -> None: ...

    class WithDensity(LineHeightSpan):
        def chooseHeight(self, arg1: java.lang.CharSequence, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: android.graphics.Paint.FontMetricsInt, arg7: android.text.TextPaint, /) -> None: ...

    class Standard(LineHeightSpan, android.text.ParcelableSpan):
        @typing.overload
        def __init__(self, height: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, src: android.os.Parcel, /) -> None: ...
        def chooseHeight(self, text: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, spanstartv: int | java.jint | java.lang.Integer, lineHeight: int | java.jint | java.lang.Integer, fm: android.graphics.Paint.FontMetricsInt, /) -> None: ...
        def describeContents(self) -> int: ...
        def getHeight(self) -> int: ...
        def getSpanTypeId(self) -> int: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class LocaleSpan(android.text.ParcelableSpan, MetricAffectingSpan):
    @typing.overload
    def __init__(self, locales: android.os.LocaleList, /) -> None: ...
    @typing.overload
    def __init__(self, source: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, locale: java.util.Locale, /) -> None: ...
    def describeContents(self) -> int: ...
    def getLocale(self) -> java.util.Locale | None: ...
    def getLocales(self) -> android.os.LocaleList: ...
    def getSpanTypeId(self) -> int: ...
    def toString(self) -> str: ...
    def updateDrawState(self, ds: android.text.TextPaint, /) -> None: ...
    def updateMeasureState(self, paint: android.text.TextPaint, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class MaskFilterSpan(CharacterStyle, UpdateAppearance):
    def __init__(self, filter: android.graphics.MaskFilter, /) -> None: ...
    def getMaskFilter(self) -> android.graphics.MaskFilter: ...
    def toString(self) -> str: ...
    def updateDrawState(self, ds: android.text.TextPaint, /) -> None: ...

class MetricAffectingSpan(CharacterStyle, UpdateLayout):
    def __init__(self) -> None: ...
    def getUnderlying(self) -> MetricAffectingSpan: ...
    def updateMeasureState(self, arg1: android.text.TextPaint, /) -> None: ...

class NoWritingToolsSpan(android.text.ParcelableSpan):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[NoWritingToolsSpan]] = ...
    def __init__(self) -> None: ...
    def describeContents(self) -> int: ...
    def getSpanTypeId(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ParagraphStyle(java.lang.Object): ...

class QuoteSpan(LeadingMarginSpan, android.text.ParcelableSpan):
    STANDARD_COLOR: typing.ClassVar[int] = ...
    STANDARD_GAP_WIDTH_PX: typing.ClassVar[int] = ...
    STANDARD_STRIPE_WIDTH_PX: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, color: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, src: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, color: int | java.jint | java.lang.Integer, stripeWidth: int | java.jint | java.lang.Integer, gapWidth: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def drawLeadingMargin(self, c: android.graphics.Canvas, p: android.graphics.Paint, x: int | java.jint | java.lang.Integer, dir: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, baseline: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, text: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, first: bool | java.jboolean | java.lang.Boolean, layout: android.text.Layout, /) -> None: ...
    def getColor(self) -> int: ...
    def getGapWidth(self) -> int: ...
    def getLeadingMargin(self, first: bool | java.jboolean | java.lang.Boolean, /) -> int: ...
    def getSpanTypeId(self) -> int: ...
    def getStripeWidth(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class RelativeSizeSpan(android.text.ParcelableSpan, MetricAffectingSpan):
    @typing.overload
    def __init__(self, proportion: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def __init__(self, src: android.os.Parcel, /) -> None: ...
    def describeContents(self) -> int: ...
    def getSizeChange(self) -> float: ...
    def getSpanTypeId(self) -> int: ...
    def toString(self) -> str: ...
    def updateDrawState(self, ds: android.text.TextPaint, /) -> None: ...
    def updateMeasureState(self, ds: android.text.TextPaint, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ReplacementSpan(MetricAffectingSpan):
    def __init__(self) -> None: ...
    def draw(self, arg1: android.graphics.Canvas, arg2: java.lang.CharSequence, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: float | java.jfloat | java.lang.Float, arg6: int | java.jint | java.lang.Integer, arg7: int | java.jint | java.lang.Integer, arg8: int | java.jint | java.lang.Integer, arg9: android.graphics.Paint, /) -> None: ...
    def getContentDescription(self) -> java.lang.CharSequence | None: ...
    def getSize(self, arg1: android.graphics.Paint, arg2: java.lang.CharSequence, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: android.graphics.Paint.FontMetricsInt, /) -> int: ...
    def setContentDescription(self, contentDescription: java.lang.CharSequence, /) -> None: ...
    def updateDrawState(self, ds: android.text.TextPaint, /) -> None: ...
    def updateMeasureState(self, p: android.text.TextPaint, /) -> None: ...

class ScaleXSpan(android.text.ParcelableSpan, MetricAffectingSpan):
    @typing.overload
    def __init__(self, proportion: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def __init__(self, src: android.os.Parcel, /) -> None: ...
    def describeContents(self) -> int: ...
    def getScaleX(self) -> float: ...
    def getSpanTypeId(self) -> int: ...
    def toString(self) -> str: ...
    def updateDrawState(self, ds: android.text.TextPaint, /) -> None: ...
    def updateMeasureState(self, ds: android.text.TextPaint, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class StrikethroughSpan(android.text.ParcelableSpan, CharacterStyle, UpdateAppearance):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, src: android.os.Parcel, /) -> None: ...
    def describeContents(self) -> int: ...
    def getSpanTypeId(self) -> int: ...
    def toString(self) -> str: ...
    def updateDrawState(self, ds: android.text.TextPaint, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class StyleSpan(android.text.ParcelableSpan, MetricAffectingSpan):
    @typing.overload
    def __init__(self, style: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, src: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, style: int | java.jint | java.lang.Integer, fontWeightAdjustment: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def getFontWeightAdjustment(self) -> int: ...
    def getSpanTypeId(self) -> int: ...
    def getStyle(self) -> int: ...
    def toString(self) -> str: ...
    def updateDrawState(self, ds: android.text.TextPaint, /) -> None: ...
    def updateMeasureState(self, paint: android.text.TextPaint, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SubscriptSpan(android.text.ParcelableSpan, MetricAffectingSpan):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, src: android.os.Parcel, /) -> None: ...
    def describeContents(self) -> int: ...
    def getSpanTypeId(self) -> int: ...
    def toString(self) -> str: ...
    def updateDrawState(self, textPaint: android.text.TextPaint, /) -> None: ...
    def updateMeasureState(self, textPaint: android.text.TextPaint, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SuggestionRangeSpan(android.text.ParcelableSpan, CharacterStyle):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SuggestionRangeSpan]] = ...
    def __init__(self) -> None: ...
    def describeContents(self) -> int: ...
    def getBackgroundColor(self) -> int: ...
    def getSpanTypeId(self) -> int: ...
    def setBackgroundColor(self, backgroundColor: int | java.jint | java.lang.Integer, /) -> None: ...
    def updateDrawState(self, tp: android.text.TextPaint, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SuggestionSpan(android.text.ParcelableSpan, CharacterStyle):
    ACTION_SUGGESTION_PICKED: typing.ClassVar[str] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SuggestionSpan]] = ...
    FLAG_AUTO_CORRECTION: typing.ClassVar[int] = ...
    FLAG_EASY_CORRECT: typing.ClassVar[int] = ...
    FLAG_GRAMMAR_ERROR: typing.ClassVar[int] = ...
    FLAG_MISSPELLED: typing.ClassVar[int] = ...
    SUGGESTIONS_MAX_SIZE: typing.ClassVar[int] = ...
    SUGGESTION_SPAN_PICKED_AFTER: typing.ClassVar[str] = ...
    SUGGESTION_SPAN_PICKED_BEFORE: typing.ClassVar[str] = ...
    SUGGESTION_SPAN_PICKED_HASHCODE: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self, src: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, suggestions: java.chaquopy.JavaArray[java.lang.String], flags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, locale: java.util.Locale, suggestions: java.chaquopy.JavaArray[java.lang.String], flags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, locale: java.util.Locale, suggestions: java.chaquopy.JavaArray[java.lang.String], flags: int | java.jint | java.lang.Integer, notificationTargetClass: typing.Type[java.lang.Object], /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getFlags(self) -> int: ...
    def getLocale(self) -> str: ...
    def getLocaleObject(self) -> java.util.Locale | None: ...
    def getSpanTypeId(self) -> int: ...
    def getSuggestions(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getUnderlineColor(self) -> int: ...
    def hashCode(self) -> int: ...
    def setFlags(self, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def updateDrawState(self, tp: android.text.TextPaint, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SuperscriptSpan(android.text.ParcelableSpan, MetricAffectingSpan):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, src: android.os.Parcel, /) -> None: ...
    def describeContents(self) -> int: ...
    def getSpanTypeId(self) -> int: ...
    def toString(self) -> str: ...
    def updateDrawState(self, textPaint: android.text.TextPaint, /) -> None: ...
    def updateMeasureState(self, textPaint: android.text.TextPaint, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class TabStopSpan(ParagraphStyle):
    def getTabStop(self) -> int: ...

    class Standard(TabStopSpan):
        def __init__(self, offset: int | java.jint | java.lang.Integer, /) -> None: ...
        def getTabStop(self) -> int: ...
        def toString(self) -> str: ...

class TextAppearanceSpan(android.text.ParcelableSpan, MetricAffectingSpan):
    @typing.overload
    def __init__(self, src: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, appearance: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, appearance: int | java.jint | java.lang.Integer, colorList: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, family: str | java.lang.String, style: int | java.jint | java.lang.Integer, size: int | java.jint | java.lang.Integer, color: android.content.res.ColorStateList, linkColor: android.content.res.ColorStateList, /) -> None: ...
    def describeContents(self) -> int: ...
    def getFamily(self) -> str: ...
    def getFontFeatureSettings(self) -> str | None: ...
    def getFontVariationSettings(self) -> str | None: ...
    def getLetterSpacing(self) -> float: ...
    def getLinkTextColor(self) -> android.content.res.ColorStateList: ...
    def getShadowColor(self) -> int: ...
    def getShadowDx(self) -> float: ...
    def getShadowDy(self) -> float: ...
    def getShadowRadius(self) -> float: ...
    def getSpanTypeId(self) -> int: ...
    def getTextColor(self) -> android.content.res.ColorStateList: ...
    def getTextFontWeight(self) -> int: ...
    def getTextLocales(self) -> android.os.LocaleList | None: ...
    def getTextSize(self) -> int: ...
    def getTextStyle(self) -> int: ...
    def getTypeface(self) -> android.graphics.Typeface | None: ...
    def isElegantTextHeight(self) -> bool: ...
    def toString(self) -> str: ...
    def updateDrawState(self, ds: android.text.TextPaint, /) -> None: ...
    def updateMeasureState(self, ds: android.text.TextPaint, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...


_TtsSpan__SemioticClassBuilder__C = typing.TypeVar('_TtsSpan__SemioticClassBuilder__C', bound=TtsSpan.SemioticClassBuilder[java.lang.Object])  # <C>

_TtsSpan__Builder__C = typing.TypeVar('_TtsSpan__Builder__C', bound=TtsSpan.Builder[java.lang.Object])  # <C>
class TtsSpan(android.text.ParcelableSpan):
    ANIMACY_ANIMATE: typing.ClassVar[str] = ...
    ANIMACY_INANIMATE: typing.ClassVar[str] = ...
    ARG_ANIMACY: typing.ClassVar[str] = ...
    ARG_CASE: typing.ClassVar[str] = ...
    ARG_COUNTRY_CODE: typing.ClassVar[str] = ...
    ARG_CURRENCY: typing.ClassVar[str] = ...
    ARG_DAY: typing.ClassVar[str] = ...
    ARG_DENOMINATOR: typing.ClassVar[str] = ...
    ARG_DIGITS: typing.ClassVar[str] = ...
    ARG_DOMAIN: typing.ClassVar[str] = ...
    ARG_EXTENSION: typing.ClassVar[str] = ...
    ARG_FRACTIONAL_PART: typing.ClassVar[str] = ...
    ARG_FRAGMENT_ID: typing.ClassVar[str] = ...
    ARG_GENDER: typing.ClassVar[str] = ...
    ARG_HOURS: typing.ClassVar[str] = ...
    ARG_INTEGER_PART: typing.ClassVar[str] = ...
    ARG_MINUTES: typing.ClassVar[str] = ...
    ARG_MONTH: typing.ClassVar[str] = ...
    ARG_MULTIPLICITY: typing.ClassVar[str] = ...
    ARG_NUMBER: typing.ClassVar[str] = ...
    ARG_NUMBER_PARTS: typing.ClassVar[str] = ...
    ARG_NUMERATOR: typing.ClassVar[str] = ...
    ARG_PASSWORD: typing.ClassVar[str] = ...
    ARG_PATH: typing.ClassVar[str] = ...
    ARG_PORT: typing.ClassVar[str] = ...
    ARG_PROTOCOL: typing.ClassVar[str] = ...
    ARG_QUANTITY: typing.ClassVar[str] = ...
    ARG_QUERY_STRING: typing.ClassVar[str] = ...
    ARG_SECONDS: typing.ClassVar[str] = ...
    ARG_TEXT: typing.ClassVar[str] = ...
    ARG_UNIT: typing.ClassVar[str] = ...
    ARG_USERNAME: typing.ClassVar[str] = ...
    ARG_VERBATIM: typing.ClassVar[str] = ...
    ARG_WEEKDAY: typing.ClassVar[str] = ...
    ARG_YEAR: typing.ClassVar[str] = ...
    CASE_ABLATIVE: typing.ClassVar[str] = ...
    CASE_ACCUSATIVE: typing.ClassVar[str] = ...
    CASE_DATIVE: typing.ClassVar[str] = ...
    CASE_GENITIVE: typing.ClassVar[str] = ...
    CASE_INSTRUMENTAL: typing.ClassVar[str] = ...
    CASE_LOCATIVE: typing.ClassVar[str] = ...
    CASE_NOMINATIVE: typing.ClassVar[str] = ...
    CASE_VOCATIVE: typing.ClassVar[str] = ...
    GENDER_FEMALE: typing.ClassVar[str] = ...
    GENDER_MALE: typing.ClassVar[str] = ...
    GENDER_NEUTRAL: typing.ClassVar[str] = ...
    MONTH_APRIL: typing.ClassVar[int] = ...
    MONTH_AUGUST: typing.ClassVar[int] = ...
    MONTH_DECEMBER: typing.ClassVar[int] = ...
    MONTH_FEBRUARY: typing.ClassVar[int] = ...
    MONTH_JANUARY: typing.ClassVar[int] = ...
    MONTH_JULY: typing.ClassVar[int] = ...
    MONTH_JUNE: typing.ClassVar[int] = ...
    MONTH_MARCH: typing.ClassVar[int] = ...
    MONTH_MAY: typing.ClassVar[int] = ...
    MONTH_NOVEMBER: typing.ClassVar[int] = ...
    MONTH_OCTOBER: typing.ClassVar[int] = ...
    MONTH_SEPTEMBER: typing.ClassVar[int] = ...
    MULTIPLICITY_DUAL: typing.ClassVar[str] = ...
    MULTIPLICITY_PLURAL: typing.ClassVar[str] = ...
    MULTIPLICITY_SINGLE: typing.ClassVar[str] = ...
    TYPE_CARDINAL: typing.ClassVar[str] = ...
    TYPE_DATE: typing.ClassVar[str] = ...
    TYPE_DECIMAL: typing.ClassVar[str] = ...
    TYPE_DIGITS: typing.ClassVar[str] = ...
    TYPE_DURATION: typing.ClassVar[str] = ...
    TYPE_ELECTRONIC: typing.ClassVar[str] = ...
    TYPE_FRACTION: typing.ClassVar[str] = ...
    TYPE_MEASURE: typing.ClassVar[str] = ...
    TYPE_MONEY: typing.ClassVar[str] = ...
    TYPE_ORDINAL: typing.ClassVar[str] = ...
    TYPE_TELEPHONE: typing.ClassVar[str] = ...
    TYPE_TEXT: typing.ClassVar[str] = ...
    TYPE_TIME: typing.ClassVar[str] = ...
    TYPE_VERBATIM: typing.ClassVar[str] = ...
    WEEKDAY_FRIDAY: typing.ClassVar[int] = ...
    WEEKDAY_MONDAY: typing.ClassVar[int] = ...
    WEEKDAY_SATURDAY: typing.ClassVar[int] = ...
    WEEKDAY_SUNDAY: typing.ClassVar[int] = ...
    WEEKDAY_THURSDAY: typing.ClassVar[int] = ...
    WEEKDAY_TUESDAY: typing.ClassVar[int] = ...
    WEEKDAY_WEDNESDAY: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, src: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, type: str | java.lang.String, args: android.os.PersistableBundle, /) -> None: ...
    def describeContents(self) -> int: ...
    def getArgs(self) -> android.os.PersistableBundle: ...
    def getSpanTypeId(self) -> int: ...
    def getType(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class VerbatimBuilder(TtsSpan.SemioticClassBuilder[TtsSpan.VerbatimBuilder]):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, verbatim: str | java.lang.String, /) -> None: ...
        def setVerbatim(self, verbatim: str | java.lang.String, /) -> TtsSpan.VerbatimBuilder: ...

    class TimeBuilder(TtsSpan.SemioticClassBuilder[TtsSpan.TimeBuilder]):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, hours: int | java.jint | java.lang.Integer, minutes: int | java.jint | java.lang.Integer, /) -> None: ...
        def setHours(self, hours: int | java.jint | java.lang.Integer, /) -> TtsSpan.TimeBuilder: ...
        def setMinutes(self, minutes: int | java.jint | java.lang.Integer, /) -> TtsSpan.TimeBuilder: ...
        def setSeconds(self, seconds: int | java.jint | java.lang.Integer, /) -> TtsSpan.TimeBuilder: ...

    class TextBuilder(TtsSpan.SemioticClassBuilder[TtsSpan.TextBuilder]):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, text: str | java.lang.String, /) -> None: ...
        def setText(self, text: str | java.lang.String, /) -> TtsSpan.TextBuilder: ...

    class TelephoneBuilder(TtsSpan.SemioticClassBuilder[TtsSpan.TelephoneBuilder]):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, numberParts: str | java.lang.String, /) -> None: ...
        def setCountryCode(self, countryCode: str | java.lang.String, /) -> TtsSpan.TelephoneBuilder: ...
        def setExtension(self, extension: str | java.lang.String, /) -> TtsSpan.TelephoneBuilder: ...
        def setNumberParts(self, numberParts: str | java.lang.String, /) -> TtsSpan.TelephoneBuilder: ...
    class SemioticClassBuilder(TtsSpan.Builder[_TtsSpan__SemioticClassBuilder__C], typing.Generic[_TtsSpan__SemioticClassBuilder__C]):
        def __init__(self, type: str | java.lang.String, /) -> None: ...
        def setAnimacy(self, animacy: str | java.lang.String, /) -> _TtsSpan__SemioticClassBuilder__C: ...
        def setCase(self, grammaticalCase: str | java.lang.String, /) -> _TtsSpan__SemioticClassBuilder__C: ...
        def setGender(self, gender: str | java.lang.String, /) -> _TtsSpan__SemioticClassBuilder__C: ...
        def setMultiplicity(self, multiplicity: str | java.lang.String, /) -> _TtsSpan__SemioticClassBuilder__C: ...

    class OrdinalBuilder(TtsSpan.SemioticClassBuilder[TtsSpan.OrdinalBuilder]):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, number: int | java.jlong | java.lang.Long, /) -> None: ...
        @typing.overload
        def __init__(self, number: str | java.lang.String, /) -> None: ...
        @typing.overload
        def setNumber(self, number: int | java.jlong | java.lang.Long, /) -> TtsSpan.OrdinalBuilder: ...
        @typing.overload
        def setNumber(self, number: str | java.lang.String, /) -> TtsSpan.OrdinalBuilder: ...

    class MoneyBuilder(TtsSpan.SemioticClassBuilder[TtsSpan.MoneyBuilder]):
        def __init__(self) -> None: ...
        def setCurrency(self, currency: str | java.lang.String, /) -> TtsSpan.MoneyBuilder: ...
        def setFractionalPart(self, fractionalPart: str | java.lang.String, /) -> TtsSpan.MoneyBuilder: ...
        @typing.overload
        def setIntegerPart(self, integerPart: int | java.jlong | java.lang.Long, /) -> TtsSpan.MoneyBuilder: ...
        @typing.overload
        def setIntegerPart(self, integerPart: str | java.lang.String, /) -> TtsSpan.MoneyBuilder: ...
        def setQuantity(self, quantity: str | java.lang.String, /) -> TtsSpan.MoneyBuilder: ...

    class MeasureBuilder(TtsSpan.SemioticClassBuilder[TtsSpan.MeasureBuilder]):
        def __init__(self) -> None: ...
        @typing.overload
        def setDenominator(self, denominator: int | java.jlong | java.lang.Long, /) -> TtsSpan.MeasureBuilder: ...
        @typing.overload
        def setDenominator(self, denominator: str | java.lang.String, /) -> TtsSpan.MeasureBuilder: ...
        def setFractionalPart(self, fractionalPart: str | java.lang.String, /) -> TtsSpan.MeasureBuilder: ...
        @typing.overload
        def setIntegerPart(self, integerPart: int | java.jlong | java.lang.Long, /) -> TtsSpan.MeasureBuilder: ...
        @typing.overload
        def setIntegerPart(self, integerPart: str | java.lang.String, /) -> TtsSpan.MeasureBuilder: ...
        @typing.overload
        def setNumber(self, number: int | java.jlong | java.lang.Long, /) -> TtsSpan.MeasureBuilder: ...
        @typing.overload
        def setNumber(self, number: str | java.lang.String, /) -> TtsSpan.MeasureBuilder: ...
        @typing.overload
        def setNumerator(self, numerator: int | java.jlong | java.lang.Long, /) -> TtsSpan.MeasureBuilder: ...
        @typing.overload
        def setNumerator(self, numerator: str | java.lang.String, /) -> TtsSpan.MeasureBuilder: ...
        def setUnit(self, unit: str | java.lang.String, /) -> TtsSpan.MeasureBuilder: ...

    class FractionBuilder(TtsSpan.SemioticClassBuilder[TtsSpan.FractionBuilder]):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, integerPart: int | java.jlong | java.lang.Long, numerator: int | java.jlong | java.lang.Long, denominator: int | java.jlong | java.lang.Long, /) -> None: ...
        @typing.overload
        def setDenominator(self, denominator: int | java.jlong | java.lang.Long, /) -> TtsSpan.FractionBuilder: ...
        @typing.overload
        def setDenominator(self, denominator: str | java.lang.String, /) -> TtsSpan.FractionBuilder: ...
        @typing.overload
        def setIntegerPart(self, integerPart: int | java.jlong | java.lang.Long, /) -> TtsSpan.FractionBuilder: ...
        @typing.overload
        def setIntegerPart(self, integerPart: str | java.lang.String, /) -> TtsSpan.FractionBuilder: ...
        @typing.overload
        def setNumerator(self, numerator: int | java.jlong | java.lang.Long, /) -> TtsSpan.FractionBuilder: ...
        @typing.overload
        def setNumerator(self, numerator: str | java.lang.String, /) -> TtsSpan.FractionBuilder: ...

    class ElectronicBuilder(TtsSpan.SemioticClassBuilder[TtsSpan.ElectronicBuilder]):
        def __init__(self) -> None: ...
        def setDomain(self, domain: str | java.lang.String, /) -> TtsSpan.ElectronicBuilder: ...
        def setEmailArguments(self, username: str | java.lang.String, domain: str | java.lang.String, /) -> TtsSpan.ElectronicBuilder: ...
        def setFragmentId(self, fragmentId: str | java.lang.String, /) -> TtsSpan.ElectronicBuilder: ...
        def setPassword(self, password: str | java.lang.String, /) -> TtsSpan.ElectronicBuilder: ...
        def setPath(self, path: str | java.lang.String, /) -> TtsSpan.ElectronicBuilder: ...
        def setPort(self, port: int | java.jint | java.lang.Integer, /) -> TtsSpan.ElectronicBuilder: ...
        def setProtocol(self, protocol: str | java.lang.String, /) -> TtsSpan.ElectronicBuilder: ...
        def setQueryString(self, queryString: str | java.lang.String, /) -> TtsSpan.ElectronicBuilder: ...
        def setUsername(self, username: str | java.lang.String, /) -> TtsSpan.ElectronicBuilder: ...

    class DurationBuilder(TtsSpan.SemioticClassBuilder[TtsSpan.DurationBuilder]):
        def __init__(self) -> None: ...
        def setHours(self, hours: int | java.jint | java.lang.Integer, /) -> TtsSpan.DurationBuilder: ...
        def setMinutes(self, minutes: int | java.jint | java.lang.Integer, /) -> TtsSpan.DurationBuilder: ...
        def setSeconds(self, seconds: int | java.jint | java.lang.Integer, /) -> TtsSpan.DurationBuilder: ...

    class DigitsBuilder(TtsSpan.SemioticClassBuilder[TtsSpan.DigitsBuilder]):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, digits: str | java.lang.String, /) -> None: ...
        def setDigits(self, digits: str | java.lang.String, /) -> TtsSpan.DigitsBuilder: ...

    class DecimalBuilder(TtsSpan.SemioticClassBuilder[TtsSpan.DecimalBuilder]):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, integerPart: str | java.lang.String, fractionalPart: str | java.lang.String, /) -> None: ...
        @typing.overload
        def __init__(self, number: float | java.jdouble | java.lang.Double, minimumFractionDigits: int | java.jint | java.lang.Integer, maximumFractionDigits: int | java.jint | java.lang.Integer, /) -> None: ...
        def setArgumentsFromDouble(self, number: float | java.jdouble | java.lang.Double, minimumFractionDigits: int | java.jint | java.lang.Integer, maximumFractionDigits: int | java.jint | java.lang.Integer, /) -> TtsSpan.DecimalBuilder: ...
        def setFractionalPart(self, fractionalPart: str | java.lang.String, /) -> TtsSpan.DecimalBuilder: ...
        @typing.overload
        def setIntegerPart(self, integerPart: int | java.jlong | java.lang.Long, /) -> TtsSpan.DecimalBuilder: ...
        @typing.overload
        def setIntegerPart(self, integerPart: str | java.lang.String, /) -> TtsSpan.DecimalBuilder: ...

    class DateBuilder(TtsSpan.SemioticClassBuilder[TtsSpan.DateBuilder]):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, weekday: int | java.jint | java.lang.Integer, day: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, year: int | java.jint | java.lang.Integer, /) -> None: ...
        def setDay(self, day: int | java.jint | java.lang.Integer, /) -> TtsSpan.DateBuilder: ...
        def setMonth(self, month: int | java.jint | java.lang.Integer, /) -> TtsSpan.DateBuilder: ...
        def setWeekday(self, weekday: int | java.jint | java.lang.Integer, /) -> TtsSpan.DateBuilder: ...
        def setYear(self, year: int | java.jint | java.lang.Integer, /) -> TtsSpan.DateBuilder: ...

    class CardinalBuilder(TtsSpan.SemioticClassBuilder[TtsSpan.CardinalBuilder]):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, number: int | java.jlong | java.lang.Long, /) -> None: ...
        @typing.overload
        def __init__(self, number: str | java.lang.String, /) -> None: ...
        @typing.overload
        def setNumber(self, number: int | java.jlong | java.lang.Long, /) -> TtsSpan.CardinalBuilder: ...
        @typing.overload
        def setNumber(self, number: str | java.lang.String, /) -> TtsSpan.CardinalBuilder: ...
    class Builder(java.lang.Object, typing.Generic[_TtsSpan__Builder__C]):
        def __init__(self, type: str | java.lang.String, /) -> None: ...
        def build(self) -> TtsSpan: ...
        def setIntArgument(self, arg: str | java.lang.String, value: int | java.jint | java.lang.Integer, /) -> _TtsSpan__Builder__C: ...
        def setLongArgument(self, arg: str | java.lang.String, value: int | java.jlong | java.lang.Long, /) -> _TtsSpan__Builder__C: ...
        def setStringArgument(self, arg: str | java.lang.String, value: str | java.lang.String, /) -> _TtsSpan__Builder__C: ...

class TypefaceSpan(android.text.ParcelableSpan, MetricAffectingSpan):
    @typing.overload
    def __init__(self, typeface: android.graphics.Typeface, /) -> None: ...
    @typing.overload
    def __init__(self, src: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, family: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def getFamily(self) -> str | None: ...
    def getSpanTypeId(self) -> int: ...
    def getTypeface(self) -> android.graphics.Typeface | None: ...
    def toString(self) -> str: ...
    def updateDrawState(self, ds: android.text.TextPaint, /) -> None: ...
    def updateMeasureState(self, paint: android.text.TextPaint, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class URLSpan(android.text.ParcelableSpan, ClickableSpan):
    @typing.overload
    def __init__(self, src: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, url: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def getSpanTypeId(self) -> int: ...
    def getURL(self) -> str: ...
    def onClick(self, widget: android.view.View, /) -> None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class UnderlineSpan(android.text.ParcelableSpan, CharacterStyle, UpdateAppearance):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, src: android.os.Parcel, /) -> None: ...
    def describeContents(self) -> int: ...
    def getSpanTypeId(self) -> int: ...
    def toString(self) -> str: ...
    def updateDrawState(self, ds: android.text.TextPaint, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class UpdateAppearance(java.lang.Object): ...

class UpdateLayout(UpdateAppearance): ...

class WrapTogetherSpan(ParagraphStyle): ...



import typing

import android.content.pm
import android.content.res.loader
import android.graphics
import android.graphics.drawable
import android.os
import android.util
import java
import java.chaquopy
import java.io
import java.lang
import java.nio.channels
import java.util
import org.xmlpull.v1

class AssetFileDescriptor(android.os.Parcelable, java.io.Closeable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AssetFileDescriptor]] = ...
    UNKNOWN_LENGTH: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, fd: android.os.ParcelFileDescriptor, startOffset: int | java.jlong | java.lang.Long, length: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def __init__(self, fd: android.os.ParcelFileDescriptor, startOffset: int | java.jlong | java.lang.Long, length: int | java.jlong | java.lang.Long, extras: android.os.Bundle, /) -> None: ...
    def close(self) -> None: ...
    def createInputStream(self) -> java.io.FileInputStream: ...
    def createOutputStream(self) -> java.io.FileOutputStream: ...
    def describeContents(self) -> int: ...
    def getDeclaredLength(self) -> int: ...
    def getExtras(self) -> android.os.Bundle: ...
    def getFileDescriptor(self) -> java.io.FileDescriptor: ...
    def getLength(self) -> int: ...
    def getParcelFileDescriptor(self) -> android.os.ParcelFileDescriptor: ...
    def getStartOffset(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class AutoCloseOutputStream(android.os.ParcelFileDescriptor.AutoCloseOutputStream):
        def __init__(self, fd: AssetFileDescriptor, /) -> None: ...
        @typing.overload
        def write(self, oneByte: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def write(self, buffer: java.chaquopy.JavaArrayJByte, /) -> None: ...
        @typing.overload
        def write(self, buffer: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, /) -> None: ...

    class AutoCloseInputStream(android.os.ParcelFileDescriptor.AutoCloseInputStream):
        def __init__(self, fd: AssetFileDescriptor, /) -> None: ...
        def available(self) -> int: ...
        def close(self) -> None: ...
        def getChannel(self) -> java.nio.channels.FileChannel: ...
        def mark(self, readlimit: int | java.jint | java.lang.Integer, /) -> None: ...
        def markSupported(self) -> bool: ...
        @typing.overload
        def read(self) -> int: ...
        @typing.overload
        def read(self, buffer: java.chaquopy.JavaArrayJByte, /) -> int: ...
        @typing.overload
        def read(self, buffer: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, /) -> int: ...
        def reset(self) -> None: ...
        def skip(self, count: int | java.jlong | java.lang.Long, /) -> int: ...

class AssetManager(java.lang.AutoCloseable):
    ACCESS_BUFFER: typing.ClassVar[int] = ...
    ACCESS_RANDOM: typing.ClassVar[int] = ...
    ACCESS_STREAMING: typing.ClassVar[int] = ...
    ACCESS_UNKNOWN: typing.ClassVar[int] = ...
    def close(self) -> None: ...
    def finalize(self) -> None: ...
    def getLocales(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def list(self, path: str | java.lang.String, /) -> java.chaquopy.JavaArray[java.lang.String] | None: ...
    @typing.overload
    def open(self, fileName: str | java.lang.String, /) -> java.io.InputStream: ...
    @typing.overload
    def open(self, fileName: str | java.lang.String, accessMode: int | java.jint | java.lang.Integer, /) -> java.io.InputStream: ...
    def openFd(self, fileName: str | java.lang.String, /) -> AssetFileDescriptor: ...
    @typing.overload
    def openNonAssetFd(self, fileName: str | java.lang.String, /) -> AssetFileDescriptor: ...
    @typing.overload
    def openNonAssetFd(self, cookie: int | java.jint | java.lang.Integer, fileName: str | java.lang.String, /) -> AssetFileDescriptor: ...
    @typing.overload
    def openXmlResourceParser(self, fileName: str | java.lang.String, /) -> XmlResourceParser: ...
    @typing.overload
    def openXmlResourceParser(self, cookie: int | java.jint | java.lang.Integer, fileName: str | java.lang.String, /) -> XmlResourceParser: ...

    class AssetInputStream(java.io.InputStream):
        def available(self) -> int: ...
        def close(self) -> None: ...
        def finalize(self) -> None: ...
        def mark(self, readlimit: int | java.jint | java.lang.Integer, /) -> None: ...
        def markSupported(self) -> bool: ...
        @typing.overload
        def read(self) -> int: ...
        @typing.overload
        def read(self, b: java.chaquopy.JavaArrayJByte, /) -> int: ...
        @typing.overload
        def read(self, b: java.chaquopy.JavaArrayJByte, off: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> int: ...
        def reset(self) -> None: ...
        def skip(self, n: int | java.jlong | java.lang.Long, /) -> int: ...

class ColorStateList(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ColorStateList]] = ...
    def __init__(self, states: java.chaquopy.JavaArray[java.chaquopy.JavaArrayJInt], colors: java.chaquopy.JavaArrayJInt, /) -> None: ...
    @typing.overload
    @staticmethod
    def createFromXml(r: Resources, parser: org.xmlpull.v1.XmlPullParser, /) -> ColorStateList: ...
    @typing.overload
    @staticmethod
    def createFromXml(r: Resources, parser: org.xmlpull.v1.XmlPullParser, theme: Resources.Theme, /) -> ColorStateList: ...
    def describeContents(self) -> int: ...
    def getChangingConfigurations(self) -> int: ...
    def getColorForState(self, stateSet: java.chaquopy.JavaArrayJInt, defaultColor: int | java.jint | java.lang.Integer, /) -> int: ...
    def getDefaultColor(self) -> int: ...
    def isOpaque(self) -> bool: ...
    def isStateful(self) -> bool: ...
    def toString(self) -> str: ...
    @staticmethod
    def valueOf(color: int | java.jint | java.lang.Integer, /) -> ColorStateList: ...
    def withAlpha(self, alpha: int | java.jint | java.lang.Integer, /) -> ColorStateList: ...
    def withLStar(self, lStar: float | java.jfloat | java.lang.Float, /) -> ColorStateList: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class Configuration(android.os.Parcelable, java.lang.Comparable[Configuration]):
    COLOR_MODE_HDR_MASK: typing.ClassVar[int] = ...
    COLOR_MODE_HDR_NO: typing.ClassVar[int] = ...
    COLOR_MODE_HDR_SHIFT: typing.ClassVar[int] = ...
    COLOR_MODE_HDR_UNDEFINED: typing.ClassVar[int] = ...
    COLOR_MODE_HDR_YES: typing.ClassVar[int] = ...
    COLOR_MODE_UNDEFINED: typing.ClassVar[int] = ...
    COLOR_MODE_WIDE_COLOR_GAMUT_MASK: typing.ClassVar[int] = ...
    COLOR_MODE_WIDE_COLOR_GAMUT_NO: typing.ClassVar[int] = ...
    COLOR_MODE_WIDE_COLOR_GAMUT_UNDEFINED: typing.ClassVar[int] = ...
    COLOR_MODE_WIDE_COLOR_GAMUT_YES: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Configuration]] = ...
    DENSITY_DPI_UNDEFINED: typing.ClassVar[int] = ...
    FONT_WEIGHT_ADJUSTMENT_UNDEFINED: typing.ClassVar[int] = ...
    GRAMMATICAL_GENDER_FEMININE: typing.ClassVar[int] = ...
    GRAMMATICAL_GENDER_MASCULINE: typing.ClassVar[int] = ...
    GRAMMATICAL_GENDER_NEUTRAL: typing.ClassVar[int] = ...
    GRAMMATICAL_GENDER_NOT_SPECIFIED: typing.ClassVar[int] = ...
    HARDKEYBOARDHIDDEN_NO: typing.ClassVar[int] = ...
    HARDKEYBOARDHIDDEN_UNDEFINED: typing.ClassVar[int] = ...
    HARDKEYBOARDHIDDEN_YES: typing.ClassVar[int] = ...
    KEYBOARDHIDDEN_NO: typing.ClassVar[int] = ...
    KEYBOARDHIDDEN_UNDEFINED: typing.ClassVar[int] = ...
    KEYBOARDHIDDEN_YES: typing.ClassVar[int] = ...
    KEYBOARD_12KEY: typing.ClassVar[int] = ...
    KEYBOARD_NOKEYS: typing.ClassVar[int] = ...
    KEYBOARD_QWERTY: typing.ClassVar[int] = ...
    KEYBOARD_UNDEFINED: typing.ClassVar[int] = ...
    MNC_ZERO: typing.ClassVar[int] = ...
    NAVIGATIONHIDDEN_NO: typing.ClassVar[int] = ...
    NAVIGATIONHIDDEN_UNDEFINED: typing.ClassVar[int] = ...
    NAVIGATIONHIDDEN_YES: typing.ClassVar[int] = ...
    NAVIGATION_DPAD: typing.ClassVar[int] = ...
    NAVIGATION_NONAV: typing.ClassVar[int] = ...
    NAVIGATION_TRACKBALL: typing.ClassVar[int] = ...
    NAVIGATION_UNDEFINED: typing.ClassVar[int] = ...
    NAVIGATION_WHEEL: typing.ClassVar[int] = ...
    ORIENTATION_LANDSCAPE: typing.ClassVar[int] = ...
    ORIENTATION_PORTRAIT: typing.ClassVar[int] = ...
    ORIENTATION_SQUARE: typing.ClassVar[int] = ...
    ORIENTATION_UNDEFINED: typing.ClassVar[int] = ...
    SCREENLAYOUT_LAYOUTDIR_LTR: typing.ClassVar[int] = ...
    SCREENLAYOUT_LAYOUTDIR_MASK: typing.ClassVar[int] = ...
    SCREENLAYOUT_LAYOUTDIR_RTL: typing.ClassVar[int] = ...
    SCREENLAYOUT_LAYOUTDIR_SHIFT: typing.ClassVar[int] = ...
    SCREENLAYOUT_LAYOUTDIR_UNDEFINED: typing.ClassVar[int] = ...
    SCREENLAYOUT_LONG_MASK: typing.ClassVar[int] = ...
    SCREENLAYOUT_LONG_NO: typing.ClassVar[int] = ...
    SCREENLAYOUT_LONG_UNDEFINED: typing.ClassVar[int] = ...
    SCREENLAYOUT_LONG_YES: typing.ClassVar[int] = ...
    SCREENLAYOUT_ROUND_MASK: typing.ClassVar[int] = ...
    SCREENLAYOUT_ROUND_NO: typing.ClassVar[int] = ...
    SCREENLAYOUT_ROUND_UNDEFINED: typing.ClassVar[int] = ...
    SCREENLAYOUT_ROUND_YES: typing.ClassVar[int] = ...
    SCREENLAYOUT_SIZE_LARGE: typing.ClassVar[int] = ...
    SCREENLAYOUT_SIZE_MASK: typing.ClassVar[int] = ...
    SCREENLAYOUT_SIZE_NORMAL: typing.ClassVar[int] = ...
    SCREENLAYOUT_SIZE_SMALL: typing.ClassVar[int] = ...
    SCREENLAYOUT_SIZE_UNDEFINED: typing.ClassVar[int] = ...
    SCREENLAYOUT_SIZE_XLARGE: typing.ClassVar[int] = ...
    SCREENLAYOUT_UNDEFINED: typing.ClassVar[int] = ...
    SCREEN_HEIGHT_DP_UNDEFINED: typing.ClassVar[int] = ...
    SCREEN_WIDTH_DP_UNDEFINED: typing.ClassVar[int] = ...
    SMALLEST_SCREEN_WIDTH_DP_UNDEFINED: typing.ClassVar[int] = ...
    TOUCHSCREEN_FINGER: typing.ClassVar[int] = ...
    TOUCHSCREEN_NOTOUCH: typing.ClassVar[int] = ...
    TOUCHSCREEN_STYLUS: typing.ClassVar[int] = ...
    TOUCHSCREEN_UNDEFINED: typing.ClassVar[int] = ...
    UI_MODE_NIGHT_MASK: typing.ClassVar[int] = ...
    UI_MODE_NIGHT_NO: typing.ClassVar[int] = ...
    UI_MODE_NIGHT_UNDEFINED: typing.ClassVar[int] = ...
    UI_MODE_NIGHT_YES: typing.ClassVar[int] = ...
    UI_MODE_TYPE_APPLIANCE: typing.ClassVar[int] = ...
    UI_MODE_TYPE_CAR: typing.ClassVar[int] = ...
    UI_MODE_TYPE_DESK: typing.ClassVar[int] = ...
    UI_MODE_TYPE_MASK: typing.ClassVar[int] = ...
    UI_MODE_TYPE_NORMAL: typing.ClassVar[int] = ...
    UI_MODE_TYPE_TELEVISION: typing.ClassVar[int] = ...
    UI_MODE_TYPE_UNDEFINED: typing.ClassVar[int] = ...
    UI_MODE_TYPE_VR_HEADSET: typing.ClassVar[int] = ...
    UI_MODE_TYPE_WATCH: typing.ClassVar[int] = ...
    colorMode: int = ...
    densityDpi: int = ...
    fontScale: float = ...
    fontWeightAdjustment: int = ...
    hardKeyboardHidden: int = ...
    keyboard: int = ...
    keyboardHidden: int = ...
    locale: java.util.Locale = ...
    mcc: int = ...
    mnc: int = ...
    navigation: int = ...
    navigationHidden: int = ...
    orientation: int = ...
    screenHeightDp: int = ...
    screenLayout: int = ...
    screenWidthDp: int = ...
    smallestScreenWidthDp: int = ...
    touchscreen: int = ...
    uiMode: int = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, o: Configuration, /) -> None: ...
    def compareTo(self, that: Configuration, /) -> int: ...
    def describeContents(self) -> int: ...
    def diff(self, delta: Configuration, /) -> int: ...
    @typing.overload
    def equals(self, that: Configuration, /) -> bool: ...
    @typing.overload
    def equals(self, that: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def generateDelta(base: Configuration, change: Configuration, /) -> Configuration: ...
    def getGrammaticalGender(self) -> int: ...
    def getLayoutDirection(self) -> int: ...
    def getLocales(self) -> android.os.LocaleList: ...
    def hashCode(self) -> int: ...
    def isLayoutSizeAtLeast(self, size: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isNightModeActive(self) -> bool: ...
    def isScreenHdr(self) -> bool: ...
    def isScreenRound(self) -> bool: ...
    def isScreenWideColorGamut(self) -> bool: ...
    @staticmethod
    def needNewResources(configChanges: int | java.jint | java.lang.Integer, interestingChanges: int | java.jint | java.lang.Integer, /) -> bool: ...
    def readFromParcel(self, source: android.os.Parcel, /) -> None: ...
    def setLayoutDirection(self, loc: java.util.Locale, /) -> None: ...
    def setLocale(self, loc: java.util.Locale, /) -> None: ...
    def setLocales(self, locales: android.os.LocaleList, /) -> None: ...
    def setTo(self, o: Configuration, /) -> None: ...
    def setToDefaults(self) -> None: ...
    def toString(self) -> str: ...
    def updateFrom(self, delta: Configuration, /) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class FontScaleConverter(java.lang.Object):
    def convertDpToSp(self, arg1: float | java.jfloat | java.lang.Float, /) -> float: ...
    def convertSpToDp(self, arg1: float | java.jfloat | java.lang.Float, /) -> float: ...
    @staticmethod
    def forScale(fontScale: float | java.jfloat | java.lang.Float, /) -> FontScaleConverter | None: ...
    @staticmethod
    def isNonLinearFontScalingActive(fontScale: float | java.jfloat | java.lang.Float, /) -> bool: ...

class ObbInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ObbInfo]] = ...
    OBB_OVERLAY: typing.ClassVar[int] = ...
    filename: str = ...
    flags: int = ...
    packageName: str = ...
    version: int = ...
    def describeContents(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, parcelableFlags: int | java.jint | java.lang.Integer, /) -> None: ...

class ObbScanner(java.lang.Object):
    @staticmethod
    def getObbInfo(filePath: str | java.lang.String, /) -> ObbInfo: ...

class Resources(java.lang.Object):
    ID_NULL: typing.ClassVar[int] = ...
    def __init__(self, assets: AssetManager, metrics: android.util.DisplayMetrics, config: Configuration, /) -> None: ...
    def addLoaders(self, *loaders: android.content.res.loader.ResourcesLoader) -> None: ...
    def finishPreloading(self) -> None: ...
    def flushLayoutCache(self) -> None: ...
    def getAnimation(self, id: int | java.jint | java.lang.Integer, /) -> XmlResourceParser: ...
    def getAssets(self) -> AssetManager: ...
    @staticmethod
    def getAttributeSetSourceResId(set: android.util.AttributeSet, /) -> int: ...
    def getBoolean(self, id: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def getColor(self, id: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def getColor(self, id: int | java.jint | java.lang.Integer, theme: Resources.Theme, /) -> int: ...
    @typing.overload
    def getColorStateList(self, id: int | java.jint | java.lang.Integer, /) -> ColorStateList: ...
    @typing.overload
    def getColorStateList(self, id: int | java.jint | java.lang.Integer, theme: Resources.Theme, /) -> ColorStateList: ...
    def getConfiguration(self) -> Configuration: ...
    def getDimension(self, id: int | java.jint | java.lang.Integer, /) -> float: ...
    def getDimensionPixelOffset(self, id: int | java.jint | java.lang.Integer, /) -> int: ...
    def getDimensionPixelSize(self, id: int | java.jint | java.lang.Integer, /) -> int: ...
    def getDisplayMetrics(self) -> android.util.DisplayMetrics: ...
    @typing.overload
    def getDrawable(self, id: int | java.jint | java.lang.Integer, /) -> android.graphics.drawable.Drawable: ...
    @typing.overload
    def getDrawable(self, id: int | java.jint | java.lang.Integer, theme: Resources.Theme, /) -> android.graphics.drawable.Drawable: ...
    @typing.overload
    def getDrawableForDensity(self, id: int | java.jint | java.lang.Integer, density: int | java.jint | java.lang.Integer, /) -> android.graphics.drawable.Drawable | None: ...
    @typing.overload
    def getDrawableForDensity(self, id: int | java.jint | java.lang.Integer, density: int | java.jint | java.lang.Integer, theme: Resources.Theme, /) -> android.graphics.drawable.Drawable | None: ...
    def getFloat(self, id: int | java.jint | java.lang.Integer, /) -> float: ...
    def getFont(self, id: int | java.jint | java.lang.Integer, /) -> android.graphics.Typeface: ...
    def getFraction(self, id: int | java.jint | java.lang.Integer, base: int | java.jint | java.lang.Integer, pbase: int | java.jint | java.lang.Integer, /) -> float: ...
    def getIdentifier(self, name: str | java.lang.String, defType: str | java.lang.String, defPackage: str | java.lang.String, /) -> int: ...
    def getIntArray(self, id: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt: ...
    def getInteger(self, id: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLayout(self, id: int | java.jint | java.lang.Integer, /) -> XmlResourceParser: ...
    def getMovie(self, id: int | java.jint | java.lang.Integer, /) -> android.graphics.Movie: ...
    @typing.overload
    def getQuantityString(self, id: int | java.jint | java.lang.Integer, quantity: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def getQuantityString(self, id: int | java.jint | java.lang.Integer, quantity: int | java.jint | java.lang.Integer, /, *formatArgs: java.lang.Object) -> str: ...
    def getQuantityText(self, id: int | java.jint | java.lang.Integer, quantity: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
    def getResourceEntryName(self, resid: int | java.jint | java.lang.Integer, /) -> str: ...
    def getResourceName(self, resid: int | java.jint | java.lang.Integer, /) -> str: ...
    def getResourcePackageName(self, resid: int | java.jint | java.lang.Integer, /) -> str: ...
    def getResourceTypeName(self, resid: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def getString(self, id: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def getString(self, id: int | java.jint | java.lang.Integer, /, *formatArgs: java.lang.Object) -> str: ...
    def getStringArray(self, id: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArray[java.lang.String]: ...
    @staticmethod
    def getSystem() -> Resources: ...
    @typing.overload
    def getText(self, id: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
    @typing.overload
    def getText(self, id: int | java.jint | java.lang.Integer, def_: java.lang.CharSequence, /) -> java.lang.CharSequence: ...
    def getTextArray(self, id: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArray[java.lang.CharSequence]: ...
    @typing.overload
    def getValue(self, id: int | java.jint | java.lang.Integer, outValue: android.util.TypedValue, resolveRefs: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def getValue(self, name: str | java.lang.String, outValue: android.util.TypedValue, resolveRefs: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def getValueForDensity(self, id: int | java.jint | java.lang.Integer, density: int | java.jint | java.lang.Integer, outValue: android.util.TypedValue, resolveRefs: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def getXml(self, id: int | java.jint | java.lang.Integer, /) -> XmlResourceParser: ...
    def newTheme(self) -> Resources.Theme: ...
    def obtainAttributes(self, set: android.util.AttributeSet, attrs: java.chaquopy.JavaArrayJInt, /) -> TypedArray: ...
    def obtainTypedArray(self, id: int | java.jint | java.lang.Integer, /) -> TypedArray: ...
    @typing.overload
    def openRawResource(self, id: int | java.jint | java.lang.Integer, /) -> java.io.InputStream: ...
    @typing.overload
    def openRawResource(self, id: int | java.jint | java.lang.Integer, value: android.util.TypedValue, /) -> java.io.InputStream: ...
    def openRawResourceFd(self, id: int | java.jint | java.lang.Integer, /) -> AssetFileDescriptor: ...
    def parseBundleExtra(self, tagName: str | java.lang.String, attrs: android.util.AttributeSet, outBundle: android.os.Bundle, /) -> None: ...
    def parseBundleExtras(self, parser: XmlResourceParser, outBundle: android.os.Bundle, /) -> None: ...
    @staticmethod
    def registerResourcePaths(uniqueId: str | java.lang.String, appInfo: android.content.pm.ApplicationInfo, /) -> None: ...
    def removeLoaders(self, *loaders: android.content.res.loader.ResourcesLoader) -> None: ...
    def updateConfiguration(self, config: Configuration, metrics: android.util.DisplayMetrics, /) -> None: ...

    class Theme(java.lang.Object):
        def applyStyle(self, resId: int | java.jint | java.lang.Integer, force: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def dump(self, priority: int | java.jint | java.lang.Integer, tag: str | java.lang.String, prefix: str | java.lang.String, /) -> None: ...
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getAttributeResolutionStack(self, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, explicitStyleRes: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt: ...
        def getChangingConfigurations(self) -> int: ...
        def getDrawable(self, id: int | java.jint | java.lang.Integer, /) -> android.graphics.drawable.Drawable: ...
        def getExplicitStyle(self, set: android.util.AttributeSet, /) -> int: ...
        def getResources(self) -> Resources: ...
        def hashCode(self) -> int: ...
        @typing.overload
        def obtainStyledAttributes(self, attrs: java.chaquopy.JavaArrayJInt, /) -> TypedArray: ...
        @typing.overload
        def obtainStyledAttributes(self, resId: int | java.jint | java.lang.Integer, attrs: java.chaquopy.JavaArrayJInt, /) -> TypedArray: ...
        @typing.overload
        def obtainStyledAttributes(self, set: android.util.AttributeSet, attrs: java.chaquopy.JavaArrayJInt, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> TypedArray: ...
        def rebase(self) -> None: ...
        def resolveAttribute(self, resid: int | java.jint | java.lang.Integer, outValue: android.util.TypedValue, resolveRefs: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
        def setTo(self, other: Resources.Theme, /) -> None: ...
        def toString(self) -> str: ...

    class NotFoundException(java.lang.RuntimeException):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, name: str | java.lang.String, /) -> None: ...
        @typing.overload
        def __init__(self, name: str | java.lang.String, cause: java.lang.Exception, /) -> None: ...

class TypedArray(java.lang.AutoCloseable):
    def close(self) -> None: ...
    def getBoolean(self, index: int | java.jint | java.lang.Integer, defValue: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def getChangingConfigurations(self) -> int: ...
    def getColor(self, index: int | java.jint | java.lang.Integer, defValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def getColorStateList(self, index: int | java.jint | java.lang.Integer, /) -> ColorStateList | None: ...
    def getDimension(self, index: int | java.jint | java.lang.Integer, defValue: float | java.jfloat | java.lang.Float, /) -> float: ...
    def getDimensionPixelOffset(self, index: int | java.jint | java.lang.Integer, defValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def getDimensionPixelSize(self, index: int | java.jint | java.lang.Integer, defValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def getDrawable(self, index: int | java.jint | java.lang.Integer, /) -> android.graphics.drawable.Drawable | None: ...
    def getFloat(self, index: int | java.jint | java.lang.Integer, defValue: float | java.jfloat | java.lang.Float, /) -> float: ...
    def getFont(self, index: int | java.jint | java.lang.Integer, /) -> android.graphics.Typeface | None: ...
    def getFraction(self, index: int | java.jint | java.lang.Integer, base: int | java.jint | java.lang.Integer, pbase: int | java.jint | java.lang.Integer, defValue: float | java.jfloat | java.lang.Float, /) -> float: ...
    def getIndex(self, at: int | java.jint | java.lang.Integer, /) -> int: ...
    def getIndexCount(self) -> int: ...
    def getInt(self, index: int | java.jint | java.lang.Integer, defValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def getInteger(self, index: int | java.jint | java.lang.Integer, defValue: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def getLayoutDimension(self, index: int | java.jint | java.lang.Integer, defValue: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def getLayoutDimension(self, index: int | java.jint | java.lang.Integer, name: str | java.lang.String, /) -> int: ...
    def getNonResourceString(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    def getPositionDescription(self) -> str: ...
    def getResourceId(self, index: int | java.jint | java.lang.Integer, defValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def getResources(self) -> Resources: ...
    def getSourceResourceId(self, index: int | java.jint | java.lang.Integer, defaultValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def getString(self, index: int | java.jint | java.lang.Integer, /) -> str | None: ...
    def getText(self, index: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
    def getTextArray(self, index: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArray[java.lang.CharSequence]: ...
    def getType(self, index: int | java.jint | java.lang.Integer, /) -> int: ...
    def getValue(self, index: int | java.jint | java.lang.Integer, outValue: android.util.TypedValue, /) -> bool: ...
    def hasValue(self, index: int | java.jint | java.lang.Integer, /) -> bool: ...
    def hasValueOrEmpty(self, index: int | java.jint | java.lang.Integer, /) -> bool: ...
    def length(self) -> int: ...
    def peekValue(self, index: int | java.jint | java.lang.Integer, /) -> android.util.TypedValue | None: ...
    def recycle(self) -> None: ...
    def toString(self) -> str: ...

class XmlResourceParser(android.util.AttributeSet, java.lang.AutoCloseable, org.xmlpull.v1.XmlPullParser):
    def close(self) -> None: ...
    def getAttributeNamespace(self, arg1: int | java.jint | java.lang.Integer, /) -> str: ...



import typing

import android.os
import java
import java.lang
import java.security
import javax.crypto

class FingerprintManager(java.lang.Object):
    FINGERPRINT_ACQUIRED_GOOD: typing.ClassVar[int] = ...
    FINGERPRINT_ACQUIRED_IMAGER_DIRTY: typing.ClassVar[int] = ...
    FINGERPRINT_ACQUIRED_INSUFFICIENT: typing.ClassVar[int] = ...
    FINGERPRINT_ACQUIRED_PARTIAL: typing.ClassVar[int] = ...
    FINGERPRINT_ACQUIRED_TOO_FAST: typing.ClassVar[int] = ...
    FINGERPRINT_ACQUIRED_TOO_SLOW: typing.ClassVar[int] = ...
    FINGERPRINT_ERROR_CANCELED: typing.ClassVar[int] = ...
    FINGERPRINT_ERROR_HW_NOT_PRESENT: typing.ClassVar[int] = ...
    FINGERPRINT_ERROR_HW_UNAVAILABLE: typing.ClassVar[int] = ...
    FINGERPRINT_ERROR_LOCKOUT: typing.ClassVar[int] = ...
    FINGERPRINT_ERROR_LOCKOUT_PERMANENT: typing.ClassVar[int] = ...
    FINGERPRINT_ERROR_NO_FINGERPRINTS: typing.ClassVar[int] = ...
    FINGERPRINT_ERROR_NO_SPACE: typing.ClassVar[int] = ...
    FINGERPRINT_ERROR_TIMEOUT: typing.ClassVar[int] = ...
    FINGERPRINT_ERROR_UNABLE_TO_PROCESS: typing.ClassVar[int] = ...
    FINGERPRINT_ERROR_USER_CANCELED: typing.ClassVar[int] = ...
    FINGERPRINT_ERROR_VENDOR: typing.ClassVar[int] = ...
    def authenticate(self, crypto: FingerprintManager.CryptoObject, cancel: android.os.CancellationSignal, flags: int | java.jint | java.lang.Integer, callback: FingerprintManager.AuthenticationCallback, handler: android.os.Handler, /) -> None: ...
    def hasEnrolledFingerprints(self) -> bool: ...
    def isHardwareDetected(self) -> bool: ...

    class CryptoObject(java.lang.Object):
        @typing.overload
        def __init__(self, signature: java.security.Signature, /) -> None: ...
        @typing.overload
        def __init__(self, cipher: javax.crypto.Cipher, /) -> None: ...
        @typing.overload
        def __init__(self, mac: javax.crypto.Mac, /) -> None: ...
        def getCipher(self) -> javax.crypto.Cipher: ...
        def getMac(self) -> javax.crypto.Mac: ...
        def getSignature(self) -> java.security.Signature: ...

    class AuthenticationResult(java.lang.Object):
        def getCryptoObject(self) -> FingerprintManager.CryptoObject: ...

    class AuthenticationCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onAuthenticationError(self, errorCode: int | java.jint | java.lang.Integer, errString: java.lang.CharSequence, /) -> None: ...
        def onAuthenticationFailed(self) -> None: ...
        def onAuthenticationHelp(self, helpCode: int | java.jint | java.lang.Integer, helpString: java.lang.CharSequence, /) -> None: ...
        def onAuthenticationSucceeded(self, result: FingerprintManager.AuthenticationResult, /) -> None: ...



import typing

import android.content
import java
import java.chaquopy
import java.lang
import java.text
import java.util

class DateFormat(java.lang.Object):
    def __init__(self) -> None: ...
    @typing.overload
    @staticmethod
    def format(inFormat: java.lang.CharSequence, inTimeInMillis: int | java.jlong | java.lang.Long, /) -> java.lang.CharSequence: ...
    @typing.overload
    @staticmethod
    def format(inFormat: java.lang.CharSequence, inDate: java.util.Calendar, /) -> java.lang.CharSequence: ...
    @typing.overload
    @staticmethod
    def format(inFormat: java.lang.CharSequence, inDate: java.util.Date, /) -> java.lang.CharSequence: ...
    @staticmethod
    def getBestDateTimePattern(locale: java.util.Locale, skeleton: str | java.lang.String, /) -> str: ...
    @staticmethod
    def getDateFormat(context: android.content.Context, /) -> java.text.DateFormat: ...
    @staticmethod
    def getDateFormatOrder(context: android.content.Context, /) -> java.chaquopy.JavaArrayJChar: ...
    @staticmethod
    def getLongDateFormat(context: android.content.Context, /) -> java.text.DateFormat: ...
    @staticmethod
    def getMediumDateFormat(context: android.content.Context, /) -> java.text.DateFormat: ...
    @staticmethod
    def getTimeFormat(context: android.content.Context, /) -> java.text.DateFormat: ...
    @staticmethod
    def is24HourFormat(context: android.content.Context, /) -> bool: ...

class DateUtils(java.lang.Object):
    ABBREV_MONTH_FORMAT: typing.ClassVar[str] = ...
    ABBREV_WEEKDAY_FORMAT: typing.ClassVar[str] = ...
    DAY_IN_MILLIS: typing.ClassVar[int] = ...
    FORMAT_12HOUR: typing.ClassVar[int] = ...
    FORMAT_24HOUR: typing.ClassVar[int] = ...
    FORMAT_ABBREV_ALL: typing.ClassVar[int] = ...
    FORMAT_ABBREV_MONTH: typing.ClassVar[int] = ...
    FORMAT_ABBREV_RELATIVE: typing.ClassVar[int] = ...
    FORMAT_ABBREV_TIME: typing.ClassVar[int] = ...
    FORMAT_ABBREV_WEEKDAY: typing.ClassVar[int] = ...
    FORMAT_CAP_AMPM: typing.ClassVar[int] = ...
    FORMAT_CAP_MIDNIGHT: typing.ClassVar[int] = ...
    FORMAT_CAP_NOON: typing.ClassVar[int] = ...
    FORMAT_CAP_NOON_MIDNIGHT: typing.ClassVar[int] = ...
    FORMAT_NO_MIDNIGHT: typing.ClassVar[int] = ...
    FORMAT_NO_MONTH_DAY: typing.ClassVar[int] = ...
    FORMAT_NO_NOON: typing.ClassVar[int] = ...
    FORMAT_NO_NOON_MIDNIGHT: typing.ClassVar[int] = ...
    FORMAT_NO_YEAR: typing.ClassVar[int] = ...
    FORMAT_NUMERIC_DATE: typing.ClassVar[int] = ...
    FORMAT_SHOW_DATE: typing.ClassVar[int] = ...
    FORMAT_SHOW_TIME: typing.ClassVar[int] = ...
    FORMAT_SHOW_WEEKDAY: typing.ClassVar[int] = ...
    FORMAT_SHOW_YEAR: typing.ClassVar[int] = ...
    FORMAT_UTC: typing.ClassVar[int] = ...
    HOUR_IN_MILLIS: typing.ClassVar[int] = ...
    HOUR_MINUTE_24: typing.ClassVar[str] = ...
    LENGTH_LONG: typing.ClassVar[int] = ...
    LENGTH_MEDIUM: typing.ClassVar[int] = ...
    LENGTH_SHORT: typing.ClassVar[int] = ...
    LENGTH_SHORTER: typing.ClassVar[int] = ...
    LENGTH_SHORTEST: typing.ClassVar[int] = ...
    MINUTE_IN_MILLIS: typing.ClassVar[int] = ...
    MONTH_DAY_FORMAT: typing.ClassVar[str] = ...
    MONTH_FORMAT: typing.ClassVar[str] = ...
    NUMERIC_MONTH_FORMAT: typing.ClassVar[str] = ...
    SECOND_IN_MILLIS: typing.ClassVar[int] = ...
    WEEKDAY_FORMAT: typing.ClassVar[str] = ...
    WEEK_IN_MILLIS: typing.ClassVar[int] = ...
    YEAR_FORMAT: typing.ClassVar[str] = ...
    YEAR_FORMAT_TWO_DIGITS: typing.ClassVar[str] = ...
    YEAR_IN_MILLIS: typing.ClassVar[int] = ...
    sameMonthTable: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    sameYearTable: typing.ClassVar[java.chaquopy.JavaArrayJInt] = ...
    def __init__(self) -> None: ...
    @typing.overload
    @staticmethod
    def formatDateRange(context: android.content.Context, startMillis: int | java.jlong | java.lang.Long, endMillis: int | java.jlong | java.lang.Long, flags: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    @staticmethod
    def formatDateRange(context: android.content.Context, formatter: java.util.Formatter, startMillis: int | java.jlong | java.lang.Long, endMillis: int | java.jlong | java.lang.Long, flags: int | java.jint | java.lang.Integer, /) -> java.util.Formatter: ...
    @typing.overload
    @staticmethod
    def formatDateRange(context: android.content.Context, formatter: java.util.Formatter, startMillis: int | java.jlong | java.lang.Long, endMillis: int | java.jlong | java.lang.Long, flags: int | java.jint | java.lang.Integer, timeZone: str | java.lang.String, /) -> java.util.Formatter: ...
    @staticmethod
    def formatDateTime(context: android.content.Context, millis: int | java.jlong | java.lang.Long, flags: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    @staticmethod
    def formatElapsedTime(elapsedSeconds: int | java.jlong | java.lang.Long, /) -> str: ...
    @typing.overload
    @staticmethod
    def formatElapsedTime(recycle: java.lang.StringBuilder, elapsedSeconds: int | java.jlong | java.lang.Long, /) -> str: ...
    @staticmethod
    def formatSameDayTime(then: int | java.jlong | java.lang.Long, now: int | java.jlong | java.lang.Long, dateStyle: int | java.jint | java.lang.Integer, timeStyle: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
    @staticmethod
    def getAMPMString(ampm: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def getDayOfWeekString(dayOfWeek: int | java.jint | java.lang.Integer, abbrev: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def getMonthString(month: int | java.jint | java.lang.Integer, abbrev: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def getRelativeDateTimeString(c: android.content.Context, time: int | java.jlong | java.lang.Long, minResolution: int | java.jlong | java.lang.Long, transitionResolution: int | java.jlong | java.lang.Long, flags: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
    @typing.overload
    @staticmethod
    def getRelativeTimeSpanString(startTime: int | java.jlong | java.lang.Long, /) -> java.lang.CharSequence: ...
    @typing.overload
    @staticmethod
    def getRelativeTimeSpanString(c: android.content.Context, millis: int | java.jlong | java.lang.Long, /) -> java.lang.CharSequence: ...
    @typing.overload
    @staticmethod
    def getRelativeTimeSpanString(time: int | java.jlong | java.lang.Long, now: int | java.jlong | java.lang.Long, minResolution: int | java.jlong | java.lang.Long, /) -> java.lang.CharSequence: ...
    @typing.overload
    @staticmethod
    def getRelativeTimeSpanString(c: android.content.Context, millis: int | java.jlong | java.lang.Long, withPreposition: bool | java.jboolean | java.lang.Boolean, /) -> java.lang.CharSequence: ...
    @typing.overload
    @staticmethod
    def getRelativeTimeSpanString(time: int | java.jlong | java.lang.Long, now: int | java.jlong | java.lang.Long, minResolution: int | java.jlong | java.lang.Long, flags: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
    @staticmethod
    def isToday(when: int | java.jlong | java.lang.Long, /) -> bool: ...

class Formatter(java.lang.Object):
    def __init__(self) -> None: ...
    @staticmethod
    def formatFileSize(context: android.content.Context, sizeBytes: int | java.jlong | java.lang.Long, /) -> str: ...
    @staticmethod
    def formatIpAddress(ipv4Address: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def formatShortFileSize(context: android.content.Context, sizeBytes: int | java.jlong | java.lang.Long, /) -> str: ...

class Time(java.lang.Object):
    EPOCH_JULIAN_DAY: typing.ClassVar[int] = ...
    FRIDAY: typing.ClassVar[int] = ...
    HOUR: typing.ClassVar[int] = ...
    MINUTE: typing.ClassVar[int] = ...
    MONDAY: typing.ClassVar[int] = ...
    MONDAY_BEFORE_JULIAN_EPOCH: typing.ClassVar[int] = ...
    MONTH: typing.ClassVar[int] = ...
    MONTH_DAY: typing.ClassVar[int] = ...
    SATURDAY: typing.ClassVar[int] = ...
    SECOND: typing.ClassVar[int] = ...
    SUNDAY: typing.ClassVar[int] = ...
    THURSDAY: typing.ClassVar[int] = ...
    TIMEZONE_UTC: typing.ClassVar[str] = ...
    TUESDAY: typing.ClassVar[int] = ...
    WEDNESDAY: typing.ClassVar[int] = ...
    WEEK_DAY: typing.ClassVar[int] = ...
    WEEK_NUM: typing.ClassVar[int] = ...
    YEAR: typing.ClassVar[int] = ...
    YEAR_DAY: typing.ClassVar[int] = ...
    allDay: bool = ...
    gmtoff: int = ...
    hour: int = ...
    isDst: int = ...
    minute: int = ...
    month: int = ...
    monthDay: int = ...
    second: int = ...
    timezone: str = ...
    weekDay: int = ...
    year: int = ...
    yearDay: int = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: Time, /) -> None: ...
    @typing.overload
    def __init__(self, timezoneId: str | java.lang.String, /) -> None: ...
    def after(self, that: Time, /) -> bool: ...
    def before(self, that: Time, /) -> bool: ...
    def clear(self, timezoneId: str | java.lang.String, /) -> None: ...
    @staticmethod
    def compare(a: Time, b: Time, /) -> int: ...
    def format(self, format: str | java.lang.String, /) -> str: ...
    def format2445(self) -> str: ...
    def format3339(self, allDay: bool | java.jboolean | java.lang.Boolean, /) -> str: ...
    def getActualMaximum(self, field: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getCurrentTimezone() -> str: ...
    @staticmethod
    def getJulianDay(millis: int | java.jlong | java.lang.Long, gmtoffSeconds: int | java.jlong | java.lang.Long, /) -> int: ...
    @staticmethod
    def getJulianMondayFromWeeksSinceEpoch(week: int | java.jint | java.lang.Integer, /) -> int: ...
    def getWeekNumber(self) -> int: ...
    @staticmethod
    def getWeeksSinceEpochFromJulianDay(julianDay: int | java.jint | java.lang.Integer, firstDayOfWeek: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def isEpoch(time: Time, /) -> bool: ...
    def normalize(self, ignoreDst: bool | java.jboolean | java.lang.Boolean, /) -> int: ...
    def parse(self, s: str | java.lang.String, /) -> bool: ...
    def parse3339(self, s: str | java.lang.String, /) -> bool: ...
    @typing.overload
    def set(self, millis: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def set(self, that: Time, /) -> None: ...
    @typing.overload
    def set(self, monthDay: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, year: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def set(self, second: int | java.jint | java.lang.Integer, minute: int | java.jint | java.lang.Integer, hour: int | java.jint | java.lang.Integer, monthDay: int | java.jint | java.lang.Integer, month: int | java.jint | java.lang.Integer, year: int | java.jint | java.lang.Integer, /) -> None: ...
    def setJulianDay(self, julianDay: int | java.jint | java.lang.Integer, /) -> int: ...
    def setToNow(self) -> None: ...
    def switchTimezone(self, timezone: str | java.lang.String, /) -> None: ...
    def toMillis(self, ignoreDst: bool | java.jboolean | java.lang.Boolean, /) -> int: ...
    def toString(self) -> str: ...
